#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 5783 $
$LastChangedDate:: 2022-04-21 09:57:03 +0200#$

This file is part of SyMSpace.

Copyright (c) 2018, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""

import os
import sys
from symspace.osutils.pathutils import Paths


def addPackagesPath(pkg_name: str = 'lcm_motorbox'):
    """
    Developer mode: packages path is added to "ExternalPythonPath" in the SyMSpace config
    User mode: Packages like "lcm_motorbox" are only in the _Scripts folder of the project
    """
    try:
        '''check if "pkg_name" is importable'''
        __import__(pkg_name)
    except ImportError:
        '''if "pkg_name" is not importable, try to extend the python path first'''
        packages_path = os.path.join(Paths.getComponentSpaceRoot(), 'src', 'packages')
        print('Adding "{}" to python path!'.format(packages_path))
        sys.path.append(packages_path)


class ComponentPaths:
    """This class provides component related (build, test, etc.) paths

       The main purpose of implementing this class was
       to make the path definitions accessible outside of java/jep/CSyMSpace
    """
    build_file = '__build__.txt'
    version_file = '__version__.txt'
    revision_file = '__revision__.txt'
    packages_file = '__packages__.json'

    @classmethod
    def getRevisonFile(cls, component_path: str):
        return os.path.join(component_path, cls.revision_file)

    @classmethod
    def getVersionFile(cls, component_path: str):
        return os.path.join(component_path, cls.version_file)

    @classmethod
    def getBuildFile(cls, component_path: str):
        return os.path.join(component_path, cls.build_file)

    @classmethod
    def getPackagesFile(cls, component_path: str):
        return os.path.join(component_path, cls.packages_file)