#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.5

$LastChangedRevision: 5487 $
$LastChangedDate:: 2022-02-09 17:19:35 +0100#$

This file is part of SyMSpace.

Copyright (c) 2020, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""
from symspace.console.script_utils import ScriptUtils
from symspace.gui.qt.form_dialog import FormDialog
from componentspace.utils.component_filter import ComponentFilter


def main(project):
    form_title = 'Set component filter'

    form_elements = [('Filter type', 'combobox', ['Requires', 'Provides', 'NodePath']),
                     ('Filter name', 'line'),
                     ('Node path', 'line'),
                     ('Requires Settings', 'label'),
                     ('Optional', 'checkbox', False),
                     ('min', 'line'),
                     ('max', 'line')
                     ]

    form_result = FormDialog.run(form_title, form_elements)

    if form_result['accept']:
        ftype = form_result['Filter type']
        fname = form_result['Filter name']
        npath = form_result['Node path']
        optional = form_result['Optional']
        n_min = form_result['min']
        n_max = form_result['max']

        if n_min != '':
            n_min = int(n_min)
        if n_max != '':
            n_max = int(n_max)

        comp_filter = ComponentFilter(project)
        if ftype == 'Requires':
            comp_filter.addRequiresType(fname, optional=optional, n_min=n_min, n_max=n_max)
        elif ftype == 'Provides':
            comp_filter.addProvides(fname)
        elif ftype == 'NodePath':
            comp_filter.addNodePath(npath, fname)
        else:
            print('Error in set_filter')
    else:
        print('Cancelled by user.')


if __name__ == '__main__':
    """
    This script creates a new python function.

    This script needs to be executed in the SyMSpace Python Console.
    """
    _params = locals()
    _project = ScriptUtils.getProject(_params)
    if _project is not None:
        ScriptUtils.run(main, _project)
    else:
        ScriptUtils.showNoProjectWarning()
