# !/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 5139 $
$LastChangedDate:: 2021-11-02 15:00:02 +0100#$

This file is part of SyMSpace.

Copyright (c) 2021, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""
if __name__ == '__main__':
    import argparse
    from symspace.osutils.pathutils import CMDParser
    from symspace.wrapper.symwrapper import SymProject
    from componentspace.base_component import Component
    from componentspace.geometry_component import FreeCADComponent
    from componentspace.geometry_component import CreoComponent
    from componentspace.geometry_component import CreoMNFComponent
    from componentspace.geometry_component import FreeCAD0p19Component

    parser = argparse.ArgumentParser(description='Execute build script')
    parser.add_argument('comp_file', help='Component Mop-File')
    parser.add_argument('build_freecad', help='Build FreeCAD test', type=int)
    parser.add_argument('build_creo', help='Build Creo test', type=int)

    args = CMDParser.jepSysArgs()
    args = parser.parse_args(args)

    comp_file = CMDParser.jepArgPath(args.comp_file)
    build_freecad = bool(args.build_freecad)
    build_creo = bool(args.build_creo)

    keys = []
    cls_types = []

    if build_freecad or build_creo:
        '''load project only if necessary'''
        sym_mdl = SymProject.load(comp_file)

        if build_freecad:
            keys.extend(['FreeCAD', 'FreeCAD0p19'])
        if build_creo:
            keys.extend(['Creo', 'Creo_MNF'])

        for key in keys:
            if sym_mdl[key] is not None:
                cls_types.append(key)

        sym_mdl.close()

    if len(cls_types) == 0:
        comp = Component(comp_file)
        comp.buildTest()
    else:
        cls_tuples = (('FreeCAD', FreeCADComponent), ('FreeCAD0p19', FreeCAD0p19Component),
                      ('Creo', CreoComponent), ('Creo_MNF', CreoMNFComponent))
        failed = False
        error_msg = []
        for cls_type, cls in cls_tuples:
            if cls_type in cls_types:
                try:
                    comp = cls(comp_file)
                    comp.buildTest()
                except Exception as ex:
                    failed = True
                    error_msg.append('{}:{}'.format(cls_type, ex))

        if failed:
            raise Exception(error_msg)

    print("Script finished")
